# Fact Sheet Relations
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/fact-sheet-relations#overview)
  * [Relation Multiplicity](https://help.sap.com/docs/leanix/ea/fact-sheet-relations#relation-multiplicity)
  * [Adding a Custom Relation](https://help.sap.com/docs/leanix/ea/fact-sheet-relations#adding-a-custom-relation)
  * [Deleting a Relation](https://help.sap.com/docs/leanix/ea/fact-sheet-relations#deleting-a-relation)
  * [Fields on Relations](https://help.sap.com/docs/leanix/ea/fact-sheet-relations#fields-on-relations)
  * [Self-Referencing Relations](https://help.sap.com/docs/leanix/ea/fact-sheet-relations#self-referencing-relations)
  * [Creating a Self-Referencing Relation](https://help.sap.com/docs/leanix/ea/fact-sheet-relations#creating-a-self-referencing-relation)
  * [Conditional Relations Between Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/fact-sheet-relations#conditional-relations-between-fact-sheet-subtypes)


View all
Relations represent connections between different fact sheets. Learn how to configure basic and advanced relations.
